==> opendirectory-0.2.1.tgz: opendirectory-0.2.1/example.php <==
#!/usr/local/bin/php -q
<?php

require_once 'DSConstants.php';

 
if(!extension_loaded('directoryServices') && !function_exists('ds_open_dir_service')) {
	dl('directoryServices.' . PHP_SHLIB_SUFFIX);
}

ds_set_separator("/");
print "calling ds_open_dir_service()\n";
$dirref = ds_open_dir_service();

if (ds_is_dir_service_running()) {
	print "service is running\n";
} else {
	print "service is NOT running\n";
}


printf("dirref: %s, status: %d, nodecount: %d\n", 
		$dirref, ds_dir_status(), ds_get_dir_node_count($dirref));

ds_data_buffer_alloc($dirref, 1024 * 2);
printf("ds_data_buffer_alloc(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

$arr = ds_get_dir_node_list($dirref);
printf("ds_get_dir_node_list(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));
print_r($arr);


$arr = ds_find_dir_nodes($dirref, "/NetInfo", DS_STARTS_WITH);
printf("ds_find_dir_nodes(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));
print_r($arr);

$noderef = ds_open_dir_node($dirref, "/NetInfo/root");
printf("ds_open_dir_node(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

ds_data_buffer_dealloc($dirref);
ds_data_buffer_alloc($dirref, 1024 * 4);


print "For some reason this function call takes a second..."
$attrs = array(DS_NATTR_AUTH_METHOD, DS_NATTR_NODE_PATH);
$info = ds_get_dir_node_info($noderef, DS_ATTRIBUTES_ALL, false);
printf("ds_get_dir_node_info(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

if ($info) {
	print_r($info);
}



if (ds_continue_data($dirref)) ds_release_continue_data($dirref);


ds_do_dir_node_auth($dirref, $noderef, $argv[1], $argv[2], $argv[3], false);
printf("ds_do_dir_node_auth(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));



do {
	$records = ds_get_record_list($dirref, $noderef, DS_STD_RECORD_TYPE_USERS, DS_RECORDS_ALL, DS_ATTRIBUTES_ALL);
	print_r($records);
} while (ds_continue_data($dirref));

if (ds_continue_data($dirref)) ds_release_continue_data($dirref);

printf("ds_get_record_list(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));


if ($rec = ds_open_record($noderef, "NewUserRecordName", DS_STD_RECORD_TYPE_USERS)) {
	printf("ds_open_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	ds_set_record_name($noderef, $rec, "setFromFunctionCall");
	printf("ds_set_record_name(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	ds_close_record($rec);
	printf("ds_close_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
} else {
	printf("ds_open_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
}

if ($rec = ds_create_record($dirref, $noderef, "NewUserRecordName", DS_STD_RECORD_TYPE_USERS, true)) {
	printf("ds_create_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	ds_add_attribute($noderef, $rec, DS_1ATTR_DISTINGUISHED_NAME, "myAttributeValue"); 
	printf("ds_add_attribute(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	ds_add_attribute($noderef, $rec, DS_1ATTR_PASSWORD, "secondAttributeValue"); 
	printf("ds_add_attribute(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	ds_add_attribute_value($noderef, $rec, DS_1ATTR_PASSWORD, array("arrayValue1", "arrayValue2")); 
	printf("ds_add_attribute_value(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	ds_remove_attribute($noderef, $rec, DS_1ATTR_PASSWORD); 
	printf("ds_remove_attribute(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	ds_set_record_type($noderef, $rec, "NewUserRecordName22"); 
	printf("ds_set_record_type(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	ds_set_record_name($noderef, $rec, "NewRecordName"); 
	printf("ds_set_record_name(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	ds_delete_record($rec);
	printf("ds_delete_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	if (is_resource($rec)) {
		ds_close_record($rec);
		printf("ds_close_record(), last status: %d, %s\n", 
				ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	}
			
} else {
	printf("ds_create_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
}


ds_verify_dir_ref_num($dirref);
printf("ds_verify_dir_ref_num(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

ds_close_dir_node($noderef);
printf("ds_close_dir_node(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

ds_data_buffer_dealloc($dirref);
printf("ds_data_buffer_dealloc(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));


ds_close_dir_service($dirref);

print "done\n";
?>

==> opendirectory-0.2.2.tgz: opendirectory-0.2.2/example.php <==
<?php

require_once 'DSConstants.php';

 
if(!extension_loaded('directoryServices') && !function_exists('ds_open_dir_service')) {
	dl('directoryServices.' . PHP_SHLIB_SUFFIX);
}


ds_set_separator("/");

print "opening directory service\n";
$dirref = ds_open_dir_service();
//$dirref = ds_open_dir_service_proxy("127.0.0.1", 1025, "username", "secret");

if (!$dirref) {
	die(ds_dir_errstr(ds_dir_status()));
}


if (ds_is_dir_service_running()) {
	print "service is running\n";
} else {
	print "service is NOT running\n";
}


printf("dirref: %s, status: %d, nodecount: %d\n", 
		$dirref, ds_dir_status(), ds_get_dir_node_count($dirref));

ds_data_buffer_alloc($dirref, 1024 * 2);
printf("ds_data_buffer_alloc(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

$arr = ds_get_dir_node_list($dirref);
printf("ds_get_dir_node_list(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));
print_r($arr);


$arr = ds_find_dir_nodes($dirref, "/NetInfo", DS_STARTS_WITH);
printf("ds_find_dir_nodes(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));
print_r($arr);


$noderef = ds_open_dir_node($dirref, "/NetInfo/root");
printf("ds_open_dir_node(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

ds_data_buffer_dealloc($dirref);
ds_data_buffer_alloc($dirref, 1024 * 4);


$attrs = array(DS_NATTR_AUTH_METHOD, DS_NATTR_NODE_PATH);
$info = ds_get_dir_node_info($noderef, DS_ATTRIBUTES_ALL, false);
printf("ds_get_dir_node_info(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

if ($info) {
	print_r($info);
}

$info = ds_do_attribute_value_search($noderef, DS_STD_RECORD_TYPE_USERS, DS_ATTRIBUTES_ALL, DS_ICONTAINS, "unknown");
printf("ds_do_attribute_value_search(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));
		
print_r($info);
if (ds_continue_data($dirref)) {
	ds_release_continue_data($dirref);
}


ds_do_dir_node_auth($dirref, $noderef, DS_STD_AUTH_NODE_NATIVE_CLEAR_TEXT_OK, false, $argv[1], $argv[2], $argv[3]);
printf("ds_do_dir_node_auth(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));


do {
	$records = ds_get_record_list($dirref, $noderef, DS_STD_RECORD_TYPE_USERS, DS_RECORDS_ALL, DS_ATTRIBUTES_ALL);
	print_r($records);
} while (ds_continue_data($dirref));

if (ds_continue_data($dirref)) {
	ds_release_continue_data($dirref);
}


printf("ds_get_record_list(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));


if ($rec = ds_open_record($noderef, "NewUserRecordName", DS_STD_RECORD_TYPE_USERS)) {
	printf("ds_open_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	print_r(ds_get_record_reference_info($dirref, $rec));
	printf("ds_get_record_reference_info(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	ds_set_record_name($noderef, $rec, "setFromFunctionCall");
	printf("ds_set_record_name(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	ds_set_record_type($noderef, $rec, DS_STD_RECORD_TYPE_USERS); 
	printf("ds_set_record_type(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	ds_close_record($rec);
	printf("ds_close_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
} else {
	printf("ds_open_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
}

if (is_resource($rec = ds_create_record($dirref, $noderef, "NewUserRecordName", DS_STD_RECORD_TYPE_USERS, true))) {
	printf("ds_create_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	ds_add_attribute($noderef, $rec, DS_1ATTR_DISTINGUISHED_NAME, "myAttributeValue"); 
	printf("ds_add_attribute(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	ds_add_attribute($noderef, $rec, DS_1ATTR_PASSWORD, "secondAttributeValue"); 
	printf("ds_add_attribute(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	ds_add_attribute_value($noderef, $rec, DS_1ATTR_PASSWORD, array("arrayValue1", "arrayValue2")); 
	printf("ds_add_attribute_value(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));

	print_r(ds_get_record_reference_info($dirref, $rec));
	printf("ds_get_record_reference_info(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
			
	print_r(ds_get_record_attribute_info($dirref, $rec, DS_1ATTR_PASSWORD));
	printf("ds_get_record_attribute_info(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	ds_remove_attribute($noderef, $rec, DS_1ATTR_PASSWORD); 
	printf("ds_remove_attribute(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));	
	
	ds_delete_record($rec);
	printf("ds_delete_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	
	if (is_resource($rec)) {
		ds_close_record($rec);
		printf("ds_close_record(), last status: %d, %s\n", 
				ds_dir_status(), ds_dir_errstr(ds_dir_status()));
	}
			
} else {
	printf("ds_create_record(), last status: %d, %s\n", 
			ds_dir_status(), ds_dir_errstr(ds_dir_status()));
}


ds_verify_dir_ref_num($dirref);
printf("ds_verify_dir_ref_num(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

ds_close_dir_node($noderef);
printf("ds_close_dir_node(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));

ds_data_buffer_dealloc($dirref);
printf("ds_data_buffer_dealloc(), last status: %d, %s\n", 
		ds_dir_status(), ds_dir_errstr(ds_dir_status()));


ds_close_dir_service($dirref);

print "done\n";
?>
